/*
 * Copyright 2006 Robert Burrell Donkin
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package rat.license;

/**
 * License for a document. 
 */
public interface ILicense {
	
	/**
	 * Is this license acceptable in a release?
	 * @return true if the license is acceptable
	 */
	public boolean isAcceptable();
    
    /**
     * Is this document generated?
     * @return true if the document is generated and so unlicensed
     */
    public boolean isGenerated();
	
	/**
	 * Short form of the name.
	 * License codes should be exactly five characters long;
	 * use upper case; may contain spaces.
	 * @return code, not null
	 */
	public String getCode();
	
	/**
	 * Full name of the license.
	 * Excludes the version number.
	 * @return name, not null
	 */
	public String getName();
	public String getVersion();
	public String getNotes();
}
