/*
 * Copyright 2006 Robert Burrell Donkin
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package rat.license.standard;

import java.util.regex.Pattern;

import rat.license.ILicense;
import rat.license.ILicenseMatcher;

public class GeneratedLicenseNotRequired extends BaseLicense implements 
        ILicenseMatcher {

    private static final Pattern[] DEFAULT_PATTERNS = {Pattern.compile(".*generated by Cayenne.*"),
        Pattern.compile(".*Generated By:JJTree:.*"), 
        Pattern.compile(".*THIS FILE IS AUTOMATICALLY GENERATED.*"),
        Pattern.compile(".*NOTE: this file is autogenerated by XBeans.*"),
        Pattern.compile(".*This file was automatically generated by .*"),
        Pattern.compile(".*# WARNING: DO NOT EDIT OR DELETE THIS WORKSPACE FILE!.*"),
        Pattern.compile(".*# Microsoft Developer Studio Generated NMAKE File.*"),
        Pattern.compile(".*# Microsoft Developer Studio Generated Build File.*"),
        Pattern.compile(".*Generated from configure.ac by autoheader.*"),
        Pattern.compile(".*generated automatically by aclocal.*"),
        Pattern.compile(".*build.xml generated by maven from project.xml.*"),
        Pattern.compile(".*This file was generated by.*")};
    
    
    private final Pattern[] linePatterns;
    private final int numberOfPatterns;
    
    public GeneratedLicenseNotRequired() {
        this(DEFAULT_PATTERNS);
    }
    
    public GeneratedLicenseNotRequired(final Pattern[] linePatterns) {
        super("GEN", "Generated Source", 
                "Generated files do not required license headers", "", true, true);
        this.linePatterns = linePatterns;
        this.numberOfPatterns = linePatterns.length;
    }

    public ILicense match(String line) {
        ILicense result = null;
        for (int i=0;i<numberOfPatterns;i++) {
            if (linePatterns[i].matcher(line).matches()) {
                result = this;
            }
        }
        return result;
    }

    public void reset() {
        // stateless
    }

}
