/*
 * Copyright 2006 Robert Burrell Donkin
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package rat.report.xml;

import java.io.IOException;

import rat.element.IElement;
import rat.element.IElementVisitor;
import rat.report.RatReport;
import rat.report.ReportFailedRuntimeException;
import rat.report.xml.writer.IXmlWriter;

class XmlReport implements RatReport {
   
    private final IElementVisitor report;
    private final IXmlWriter writer;
    
    public XmlReport(final IXmlWriter writer, IElementVisitor report) {
        this.report = report;
        this.writer = writer;
    }

    public void startReport() {
        try {
            writer.openElement("rat-report");
        } catch (IOException e) {
            throw new ReportFailedRuntimeException(e);
        }
    }

    public void endReport() {
        try {
            writer.closeDocument();
        } catch (IOException e) {
            throw new ReportFailedRuntimeException(e);
        }
    }

    public void consume(IElement element) {
        element.accept(report);
    }    
}
