/*
 * Copyright 2006 Robert Burrell Donkin
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package rat.report.xml;

import rat.element.IElementVisitor;
import rat.element.visitor.ElementVisitorMultiplexer;
import rat.element.visitor.IgnoreDirectoryElementVisitorProxy;
import rat.license.ILicenseMatcher;
import rat.report.RatReport;
import rat.report.claim.impl.xml.SimpleXmlClaimReporter;
import rat.report.xml.visitor.ElementTypeVisitor;
import rat.report.xml.visitor.report.archive.ReadableArchiveVisitor;
import rat.report.xml.visitor.report.license.LicenseReportVisitor;
import rat.report.xml.writer.IXmlWriter;

/**
 * Creates reports.
 *
 */
public class XmlReportFactory {

    
    public static final RatReport createStandardReport(final IXmlWriter writer, final ILicenseMatcher matcher) {
        final SimpleXmlClaimReporter reporter = new SimpleXmlClaimReporter(writer);
        final IElementVisitor[] reportComponents = {
                    new ElementTypeVisitor(reporter),
                    new ReadableArchiveVisitor(reporter),
                    new LicenseReportVisitor(reporter, matcher)      
        };
        return createRatReport(writer, reportComponents);
    }
    
    
    public static final RatReport createBaseReport(final IXmlWriter writer) {
        final SimpleXmlClaimReporter reporter = new SimpleXmlClaimReporter(writer);
        final IElementVisitor[] reportComponents = {new ElementTypeVisitor(reporter)};
        return createRatReport(writer, reportComponents);
    }

    public static final RatReport createRatReport(final IXmlWriter writer, final IElementVisitor[] reportComponents) {
        final IElementVisitor visitor = new IgnoreDirectoryElementVisitorProxy(new ElementVisitorMultiplexer(reportComponents));
        final RatReport result = new XmlReport(writer, visitor);
        return result;
    }
}
