/*
 * Copyright 2006 Robert Burrell Donkin
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package rat.report.xml.visitor;

import rat.element.ArchiveElement;
import rat.element.BinaryElement;
import rat.element.Directory;
import rat.element.IElement;
import rat.element.IElementVisitor;
import rat.element.NoteElement;
import rat.element.StandardContentElement;
import rat.report.ReportFailedException;
import rat.report.ReportFailedRuntimeException;
import rat.report.claim.IClaimReporter;

public final class ElementTypeVisitor implements IElementVisitor {

    private final IClaimReporter reporter;
    
    public ElementTypeVisitor(final IClaimReporter reporter) {
        this.reporter = reporter;
    }
    
    public void visit(Directory directory) {
        // DO NOTHING
    }

    public void visit(StandardContentElement standardContent) {
        claim(standardContent, "standard");
    }

    public void visit(NoteElement note) {
        claim(note, "notice");
    }

    public void visit(BinaryElement binary) {
        claim(binary, "binary");
    }

    public void visit(ArchiveElement archive) {
        claim(archive, "archive");
    }
    
    private void claim(final IElement element, final String type) {
        try {
            final String name = element.getName();
            reporter.claim(name, "type", type, false);
        } catch (ReportFailedException e) {
            throw new ReportFailedRuntimeException(e);
        }
    }
}
