/*
 * Copyright 2006 Robert Burrell Donkin
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package rat.report.xml.visitor.report.archive;

import java.io.IOException;

import rat.document.IDocumentCollection;
import rat.element.ArchiveElement;
import rat.element.ElementVisitorImpl;
import rat.report.ReportFailedException;
import rat.report.ReportFailedRuntimeException;
import rat.report.claim.IClaimReporter;

public class ReadableArchiveVisitor extends ElementVisitorImpl {

    private final IClaimReporter reporter;

    public ReadableArchiveVisitor(final IClaimReporter reporter) {
        this.reporter = reporter;
    }

    public void visit(ArchiveElement archive) {
        boolean readable = false;
        try {
            final IDocumentCollection contents = archive.read();
            if (contents != null) {
                readable = true;
            }
        } catch (IOException e) {
            readable = false;
        }
        String value = "unreadable";
        if (readable) {
            value = "readable";
        }
        try {
            final String name = archive.getName();
            reporter.claim(name, "archive-type", value, false);
        } catch (ReportFailedException e) {
            throw new ReportFailedRuntimeException(e);
        }
    }
}
